﻿/**
* @author Juan Alejandro Lam López
* @version 1.0
* @since 18/06/2019
* @Description Controller DSSQLPersonDemoController
* @Schema Person
* @Table PersonDemo
*/

using Appeon.Services.NETDataStore;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using PowerBuilder.Data;
using System;

namespace Appeon.Controllers.NETDataStore
{
    /// <summary>
    /// DSSQLPersonDemoController Class
    /// </summary>
    [Route("api/[controller]/[action]")]
    [ApiController]
    public class DSORAPersonDemoController : ControllerBase
    {
        private IDSORAPersonDemoService _service;

        /// <summary>
        /// Constructor of DSSQLPersonDemoController Class
        /// </summary>
        /// <param name="service">Represents the interface IDSSQLPersonDemoService</param>
        public DSORAPersonDemoController(IDSORAPersonDemoService service)
        {
            _service = service;
        }
        /// <summary>
        /// Retrieves data according to the SQL query defined in a PersonDemo class.
        /// "GET api/DSSQLPersonDemo/Retrieve"
        /// </summary>
        /// <returns>Return a List of PersonDemo </returns>
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status404NotFound)]
        [ProducesResponseType(StatusCodes.Status500InternalServerError)]
        public ActionResult<IDataStore> Retrieve()
        {
            try
            {
                var personDemo = _service.Retrieve();

                if (personDemo == null)
                {
                    return StatusCode(StatusCodes.Status404NotFound);
                }
                return StatusCode(StatusCodes.Status200OK, personDemo);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, ex);
            }
        }


        /// <summary>
        /// Tracks one or more database table operations (insert, update or delete).
        /// "POST api/DSSQLPersonDemo/Update"
        /// </summary>
        /// <param name="dataStore">A sequence of IDataStore objects containing data and state.</param>
        /// <returns>Returns the number of rows that are affected.</returns>
        [HttpPost]
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status204NoContent)]
        [ProducesResponseType(StatusCodes.Status500InternalServerError)]
        public ActionResult<Int32> Update(IDataStore dataStore)
        {
            try
            {
                Int32 count = _service.Update(dataStore);
                if (count == 0)
                {
                    return StatusCode(StatusCodes.Status204NoContent);
                }
                return StatusCode(StatusCodes.Status200OK, count);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, ex);
            }
        }

        /// <summary>
        /// Retrieves Max PersonID
        /// "GET api/DSORAPersonDemo/MaxId"
        /// </summary>
        /// <returns>Return a Max PersonID of Table PersonDemo </returns>
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status404NotFound)]
        [ProducesResponseType(StatusCodes.Status500InternalServerError)]
        public ActionResult<Int32> MaxId()
        {
            try
            {
                var maxId = _service.MaxId();

                if (maxId == 0)
                {
                    return StatusCode(StatusCodes.Status404NotFound);
                }
                return StatusCode(StatusCodes.Status200OK, maxId);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, ex);
            }
        }
        // GET api/MMSQLPersonDemo/GetConnection?DataBase=DBSQL02
        [HttpGet]
        public String GetConnection()
        {
            // Current DataContext's ConnectionString
            return _service.GetConnection();
        }
    }
}

