﻿/**
* @author Juan Alejandro Lam López
* @version 1.0
* @since 18/06/2019
* @Description Controller PersonDemoController
* @Schema Person
* @Table PersonDemo
*/

using Appeon.Models;
using Appeon.Services.ModelStore;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using PowerBuilder.Data;
using System;
using System.Collections.Generic;
using System.Linq;

namespace Appeon.Controllers.ModelStore
{
    /// <summary>
    /// MSORAPersonDemoController Class
    /// </summary>
    [Route("api/[controller]/[action]")]
    [ApiController]
    public class MSORAPersonDemoController : ControllerBase
    {
        private IMSORAPersonDemoService _service;


        /// <summary>
        /// Constructor of MMORAPersonDemoController Class
        /// </summary>
        /// <param name="service">Represents the interface IMMORAPersonDemoService</param>
        public MSORAPersonDemoController(IMSORAPersonDemoService service) //, SqlServerDataContext sqlServerDataContext)
        {
            _service = service;
            //    _sqlServerDataContext = sqlServerDataContext;
        }
        /// <summary>
        /// Retrieves data according to the SQL query defined in a PersonDemo class.
        /// "GET api/MMORAPersonDemo/Retrieve"
        /// "GET api/MMORAPersonDemo/Retrieve?connectionID=DB01"
        /// </summary>
        /// <returns>Return a List of PersonDemoORA </returns>
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status404NotFound)]
        [ProducesResponseType(StatusCodes.Status500InternalServerError)]
        public ActionResult<IList<PersonDemoORA>> Retrieve()
        {
            try
            {
                IList<PersonDemoORA> modelList = _service.Retrieve().ToList().ToList<PersonDemoORA>();
                if (modelList == null)
                {
                    return StatusCode(StatusCodes.Status404NotFound);
                }
                return StatusCode(StatusCodes.Status200OK, modelList);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, ex);
            }
        }



        /// <summary>
        /// Tracks one or more database table operations (insert, update or delete).
        /// "POST api/MMORAPersonDemo/TrackRange"
        /// </summary>
        /// <param name="models">A sequence of [FromBody]IModelStore&lt;PersonDemoORA&gt; objects containing data and state.</param>
        /// <returns>Returns the number of rows that are affected.</returns>
        [HttpPost]
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status204NoContent)]
        [ProducesResponseType(StatusCodes.Status500InternalServerError)]
        public ActionResult<Int32> TrackRange([FromBody]IModelStore<PersonDemoORA> models)
        {
            try
            {
                Int32 count = _service.Update(models);
                if (count == 0)
                {
                    return StatusCode(StatusCodes.Status204NoContent);
                }
                return StatusCode(StatusCodes.Status200OK, count);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, ex);
            }
        }

        /// <summary>
        /// Retrieves Max PersonID
        /// "GET api/MMORAPersonDemo/MaxId"
        /// </summary>
        /// <returns>Return a Max PersonID of Table PersonDemo </returns>
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status404NotFound)]
        [ProducesResponseType(StatusCodes.Status500InternalServerError)]
        public ActionResult<Int32> MaxId()
        {
            try
            {
                var maxId = _service.MaxId();

                if (maxId == 0)
                {
                    return StatusCode(StatusCodes.Status404NotFound);
                }
                return StatusCode(StatusCodes.Status200OK, maxId);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, ex);
            }
        }
        // GET api/sample/GetConnection?DataBase=DB02
        [HttpGet]
        public String GetConnection()
        {
            // Current DataContext's ConnectionString
            return _service.GetConnection();
        }
    }
}

