﻿/**
* @author Juan Alejandro Lam López
* @version 1.0
* @since 18/06/2019
* @Description Controller MMSQLPersonDemoController
* @Schema Person
* @Table PersonDemo
*/

using Appeon.Models;
using Appeon.Services.SqlModelMapper;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using SnapObjects.Data;
using System;
using System.Collections.Generic;
using System.Linq;

namespace Appeon.Controllers.SqlModelMapper
{
    /// <summary>
    /// MMSQLPersonDemoController Class
    /// </summary>
    [Route("api/[controller]/[action]")]
    [ApiController]
    public class MMSQLPersonDemoController : ControllerBase
    {
        private IMMSQLPersonDemoService _service;

        /// <summary>
        /// Constructor of MMSQLPersonDemoController Class
        /// </summary>
        /// <param name="service">Represents the interface IMMSQLPersonDemoService</param>
        public MMSQLPersonDemoController(IMMSQLPersonDemoService service)
        {
            _service = service;

        }
        /// <summary>
        /// Retrieves data according to the SQL query defined in a PersonDemo class.
        /// "GET api/MMSQLPersonDemo/Retrieve"
        /// "GET api/MMSQLPersonDemo/Retrieve?connectionID=DB01"
        /// </summary>
        /// <returns>Return a List of PersonDemo </returns>
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status404NotFound)]
        [ProducesResponseType(StatusCodes.Status500InternalServerError)]
        public ActionResult<List<PersonDemoSQL>> Retrieve()
        {
            try
            {
                List<PersonDemoSQL> modelList = _service.Retrieve().ToList();
                if (modelList == null)
                {
                    return StatusCode(StatusCodes.Status404NotFound);
                }
                return StatusCode(StatusCodes.Status200OK, modelList);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, ex);
            }
        }



        /// <summary>
        /// Tracks one or more database table operations (insert, update or delete).
        /// "POST api/MMSQLPersonDemo/TrackRange"
        /// </summary>
        /// <param name="models">A sequence of [FromBody]IEnumerable&lt;IModelEntry&lt;PersonDemoSQL&gt;&gt; objects containing data and state.</param>
        /// <returns>Returns the number of rows that are affected.</returns>
        [HttpPost]
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status204NoContent)]
        [ProducesResponseType(StatusCodes.Status500InternalServerError)]
        public ActionResult<Int32> TrackRange([FromBody]IEnumerable<IModelEntry<PersonDemoSQL>> models)
        {
            try
            {
                Int32 count = _service.TrackRange(models);
                if (count == 0)
                {
                    return StatusCode(StatusCodes.Status204NoContent);
                }
                return StatusCode(StatusCodes.Status200OK, count);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, ex);
            }
        }

        /// <summary>
        /// Retrieves Max PersonID
        /// "GET api/MMSQLPersonDemo/MaxId"
        /// </summary>
        /// <returns>Return a Max PersonID of Table PersonDemo </returns>
        [ProducesResponseType(StatusCodes.Status200OK)]
        [ProducesResponseType(StatusCodes.Status404NotFound)]
        [ProducesResponseType(StatusCodes.Status500InternalServerError)]
        public ActionResult<Int32> MaxId()
        {
            try
            {
                var maxId = _service.MaxId();

                if (maxId == 0)
                {
                    return StatusCode(StatusCodes.Status404NotFound);
                }
                return StatusCode(StatusCodes.Status200OK, maxId);
            }
            catch (Exception ex)
            {
                return StatusCode(StatusCodes.Status500InternalServerError, ex);
            }
        }
        // GET api/MMSQLPersonDemo/GetConnection?DataBase=DBSQL02
        [HttpGet]
        public String GetConnection()
        {
            // Current DataContext's ConnectionString
            return _service.GetConnection();
        }
    }
}

