﻿/**
* @author Juan Alejandro Lam López
* @version 1.0
* @since 18/06/2019
* @Description Model PersonDemo
* @Schema Person
* @Table PersonDemo
*/

using SnapObjects.Data;
using System;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace Appeon.Models
{
    /// <summary>
    /// Class that represents a Model of the table PersonDemo.
    /// Table Comments : Human beings involved with AdventureWorks: employees, customer contacts, and vendor contacts.
    /// </summary>
    [Table("PersonDemo", Schema = "dbo")]
    [UpdateWhereStrategy(UpdateWhereStrategy.KeyColumns)]
    public class PersonDemoSQL
    {
        /// <summary>
        /// The [Key] PersonID property represents the PersonID column in the PersonDemo table.
        /// </summary>	
        [Key]
        [Identity]
        [SqlColumn("PersonID")]
        public Int32 PersonID { get; set; }

        /// <summary>
        /// The Title property represents the Title column in the PersonDemo table.
        /// Column Comments : A courtesy title. For example, Mr. or Ms.
        /// </summary>	
        [SqlColumn("Title")]
        public String Title { get; set; }

        /// <summary>
        /// The FirstName property represents the FirstName column in the PersonDemo table.
        /// Column Comments : First name of the person.
        /// </summary>	
        [SqlColumn("FirstName")]
        public String FirstName { get; set; }

        /// <summary>
        /// The MiddleName property represents the MiddleName column in the PersonDemo table.
        /// Column Comments : Middle name or middle initial of the person.
        /// </summary>	
        [SqlColumn("MiddleName")]
        public String MiddleName { get; set; }

        /// <summary>
        /// The LastName property represents the LastName column in the PersonDemo table.
        /// Column Comments : Last name of the person.
        /// </summary>	
        [SqlColumn("LastName")]
        public String LastName { get; set; }

    }
}

