﻿/**
* @author Juan Alejandro Lam López
* @version 1.0
* @since 18/06/2019
* @Descripción Service DSSQLPersonDemoService
* @Schema Person
* @Table PersonDemo
*/

using PowerBuilder.Data;
using System;

namespace Appeon.Services.NETDataStore.Impl
{
    //Appeon DSORAPersonDemoService Service for the NetDataStore
    /// <summary>
    /// DSORAPersonDemoService Class implement the interface IDSSQLPersonDemoService
    /// </summary>
    public class DSORAPersonDemoService : IDSORAPersonDemoService
    {
        /// <summary>
        /// Represents the entry to the database, which contains the database connection information, methods for manipulating database transactions, and other easy-to-use properties.
        /// </summary>
        private readonly DataContextBaseNETDataStoreOracle _dataContext;

        /// <summary>
        /// Constructor of PersonDemoService Class
        /// </summary>
        /// <param name="dataContext">Represents the entry to the database, which contains the database connection information, methods for manipulating database transactions, and other easy-to-use properties.</param>
        public DSORAPersonDemoService(DataContextBaseNETDataStoreOracle dataContext)
        {
            //Initialize the dataContext Variable
            _dataContext = dataContext;
        }

        /// <summary>
        /// Retrieves data according to the SQL query defined in a PersonDemo class.
        /// </summary>
        /// <returns>Returns a IDataStore of D_Persondemoora class</returns>	
        public IDataStore Retrieve()
        {
            //Load the Data from table PersonDemo in the DataStore and return them as a IDataStore of the class D_Persondemo

            var dataStore = new DataStore("d_persondemoora", _dataContext);

            dataStore.Retrieve();

            return dataStore;
        }


        /// <summary>
        /// Tracks one or more database table operations (insert, update or delete).
        /// </summary>
        /// <param name="models">A sequence of IDataStore objects containing data and state.</param>
        /// <returns>Returns the number of rows that are affected.</returns>
        public Int32 Update(IDataStore models)
        {

            models.SetDataContext(_dataContext);

            var li_Rows = models.Update();

            return li_Rows;
        }

        /// <summary>
        /// SQL SELECT Max(PersonID) and returns in the result set. 
        /// All other columns and rows are ignored
        /// </summary>        
        /// <returns>Returns the Max PersonID of DBO.PersonDemo.</returns>
        public Int32 MaxId()
        {

            var sqlSelectMax = "SELECT Max(PersonID) FROM DBO.PersonDemo";

            // Executes the SQL statement and returns the query result.
            var maxId = _dataContext.SqlExecutor.Scalar<Int32>(sqlSelectMax) + 1;

            return maxId;
        }


        public String GetConnection()
        {
            // Current DataContext's ConnectionString
            return _dataContext.CurrentConnection.ConnectionString;
        }
    }
}

