﻿/**
* @author Juan Alejandro Lam López
* @version 1.0
* @since 18/06/2019
* @Descripción Service PersonDemoService
* @Schema Person
* @Table PersonDemo
*/

using Appeon.Models;
using PowerBuilder.Data;
using System;

namespace Appeon.Services.ModelStore.Impl
{
    //Appeon MSORAPersonDemoService Service for the ModelStore
    /// <summary>
    /// ORAMMPersonDemoService Class implement the interface IMSORAPersonDemoService
    /// </summary>
    public class MSORAPersonDemoService : IMSORAPersonDemoService
    {
        /// <summary>
        /// Represents the entry to the database, which contains the database connection information, methods for manipulating database transactions, and other easy-to-use properties.
        /// </summary>
        private readonly DataContextBaseModelStoreOracle _dataContext;

        /// <summary>
        /// Constructor of MMORAPersonDemoService Class
        /// </summary>
        /// <param name="dataContext">Represents the entry to the database, which contains the database connection information, methods for manipulating database transactions, and other easy-to-use properties.</param>
        public MSORAPersonDemoService(DataContextBaseModelStoreOracle dataContext)
        {
            //Initialize the dataContext Variable
            _dataContext = dataContext;
        }

        /// <summary>
        /// Retrieves data according to the SQL query defined in a PersonDemo class.
        /// </summary>
        /// <returns>Returns a List of PersonDemoORA class</returns>	
        public IModelStore<PersonDemoORA> Retrieve()
        {
            //Load the Data from table PersonDemo in the ModelStore and return them as a list of the class PersonDemoSQL
            var modelStore = new ModelStore<PersonDemoORA>();

            modelStore.Retrieve(_dataContext);

            return modelStore;
        }


        /// <summary>
        /// Tracks one or more database table operations (insert, update or delete).
        /// </summary>
        /// <param name="models">A sequence of IEnumerable&lt;IModelEntry&lt;PersonDemoORA&gt;&gt; objects containing data and state.</param>
        /// <returns>Returns the number of rows that are affected.</returns>
        public Int32 Update(IModelStore<PersonDemoORA> models)
        {
            return models.SaveChanges(_dataContext).AffectedCount;
        }


        /// <summary>
        /// SQL SELECT Max(PersonID) and returns in the result set. 
        /// All other columns and rows are ignored
        /// </summary>        
        /// <returns>Returns the Max PersonID of DBO.PersonDemo.</returns>
        public Int32 MaxId()
        {

            var sqlSelectMax = "SELECT Max(PersonID) FROM DBO.PersonDemo";

            // Executes the SQL statement and returns the query result.
            var maxId = _dataContext.SqlExecutor.Scalar<Int32>(sqlSelectMax) + 1;

            return maxId;
        }


        public String GetConnection()
        {
            // Current DataContext's ConnectionString
            return _dataContext.CurrentConnection.ConnectionString;
        }

    }
}

