﻿/**
* @author Juan Alejandro Lam López
* @version 1.0
* @since 18/06/2019
* @Descripción Service PersonDemoService
* @Schema Person
* @Table PersonDemo
*/

using Appeon.Models;
using Appeon.Services.SqlModelMapper;
using SnapObjects.Data;
using SnapObjects.Data.SqlServer;
using System;
using System.Collections.Generic;

namespace Appeon.Services.SqlModelMapper.Impl
{
    //Appeon MMORAPersonDemoService Service for the SqlModelMapper
    /// <summary>
    /// ORAMMPersonDemoService Class implement the interface IPersonDemoService
    /// </summary>
    public class MMORAPersonDemoService : IMMORAPersonDemoService
    {
        /// <summary>
        /// Represents the entry to the database, which contains the database connection information, methods for manipulating database transactions, and other easy-to-use properties.
        /// </summary>
        private readonly DataContextBaseSqlModelMapperOracle _dataContext;

        /// <summary>
        /// Constructor of MMORAPersonDemoService Class
        /// </summary>
        /// <param name="dataContext">Represents the entry to the database, which contains the database connection information, methods for manipulating database transactions, and other easy-to-use properties.</param>
        public MMORAPersonDemoService(DataContextBaseSqlModelMapperOracle dataContext)
        {
            //Initialize the dataContext Variable
            _dataContext = dataContext;
        }

        /// <summary>
        /// Retrieves data according to the SQL query defined in a PersonDemo class.
        /// </summary>
        /// <returns>Returns a List of PersonDemoORA class</returns>	
        public List<PersonDemoORA> Retrieve()
        {
            //Load the Data from table PersonDemo in the SqlModelMapper and return them as a list of the class PersonDemoORA
            return _dataContext.SqlModelMapper.Load<PersonDemoORA>().ToList();
        }


        /// <summary>
        /// Tracks one or more database table operations (insert, update or delete).
        /// </summary>
        /// <param name="models">A sequence of IEnumerable&lt;IModelEntry&lt;PersonDemoORA&gt;&gt; objects containing data and state.</param>
        /// <returns>Returns the number of rows that are affected.</returns>
        public Int32 TrackRange(IEnumerable<IModelEntry<PersonDemoORA>> models)
        {
            // SqlModelMapper Variable Track the Create, Delete, Insert SQL Queries
            _dataContext.SqlModelMapper.TrackRange<PersonDemoORA>(models);
            //Save the changes and catch the total amount of saved rows and Return the total amount of saved rows
            return _dataContext.SqlModelMapper.SaveChanges().AffectedCount;
        }

        /// <summary>
        /// SQL SELECT Max(PersonID) and returns in the result set. 
        /// All other columns and rows are ignored
        /// </summary>        
        /// <returns>Returns the Max PersonID of DBO.PersonDemo.</returns>
        public Int32 MaxId()
        {
       
            var sqlSelectMax = "SELECT Max(PersonID) FROM DBO.PersonDemo";

            // Executes the SQL statement and returns the query result.
            var maxId = _dataContext.SqlExecutor.Scalar<Int32>(sqlSelectMax) + 1;

            return maxId;
        }
        public String GetConnection()
        {
            // Current DataContext's ConnectionString
            return _dataContext.CurrentConnection.ConnectionString;
        }    }
}

