﻿/**
* @author Juan Alejandro Lam López
* @version 1.0
* @since 18/06/2019
* @Descripción Service PersonDemoService
* @Schema Person
* @Table PersonDemo
*/

using Appeon.Models;
using SnapObjects.Data;
using System;
using System.Collections.Generic;

namespace Appeon.Services.SqlModelMapper.Impl
{
    //Appeon MMSQLPersonDemoService Service for the SqlModelMapper
    /// <summary>
    /// SQLMMPersonDemoService Class implement the interface IMMSQLPersonDemoService
    /// </summary>
    public class MMSQLPersonDemoService : IMMSQLPersonDemoService
    {
        /// <summary>
        /// Represents the entry to the database, which contains the database connection information, methods for manipulating database transactions, and other easy-to-use properties.
        /// </summary>
        private readonly DataContextBaseSqlModelMapperSqlServer _dataContext;

        /// <summary>
        /// Constructor of PersonDemoService Class
        /// </summary>
        /// <param name="dataContext">Represents the entry to the database, which contains the database connection information, methods for manipulating database transactions, and other easy-to-use properties.</param>
        public MMSQLPersonDemoService(DataContextBaseSqlModelMapperSqlServer dataContext)
        {
            //Initialize the dataContext Variable
            _dataContext = dataContext;
        }

        /// <summary>
        /// Retrieves data according to the SQL query defined in a PersonDemoSQL class.
        /// </summary>
        /// <returns>Returns a List of PersonDemoSQL class</returns>	
        public List<PersonDemoSQL> Retrieve()
        {
            //Load the Data from table PersonDemo in the SqlModelMapper and return them as a list of the class PersonDemoSQL
            return _dataContext.SqlModelMapper.Load<PersonDemoSQL>().ToList();
        }


        /// <summary>
        /// Tracks one or more database table operations (insert, update or delete).
        /// </summary>
        /// <param name="models">A sequence of IEnumerable&lt;IModelEntry&lt;PersonDemoSQL&gt;&gt;  objects containing data and state.</param>
        /// <returns>Returns the number of rows that are affected.</returns>
        public Int32 TrackRange(IEnumerable<IModelEntry<PersonDemoSQL>> models)
        {
            // SqlModelMapper Variable Track the Create, Delete, Insert SQL Queries
            _dataContext.SqlModelMapper.TrackRange<PersonDemoSQL>(models);
            //Save the changes and catch the total amount of saved rows and Return the total amount of saved rows
            return _dataContext.SqlModelMapper.SaveChanges().AffectedCount;
        }

        /// <summary>
        /// SQL SELECT Max(PersonID) and returns in the result set. 
        /// All other columns and rows are ignored
        /// </summary>        
        /// <returns>Returns the Max PersonID of DBO.PersonDemo.</returns>
        public Int32 MaxId()
        {

            var sqlSelectMax = "SELECT Max(PersonID) FROM DBO.PersonDemo";

            // Executes the SQL statement and returns the query result.
            var maxId = _dataContext.SqlExecutor.Scalar<Int32>(sqlSelectMax) + 1;

            return maxId;
        }


        public String GetConnection()
        {
            // Current DataContext's ConnectionString
            return _dataContext.CurrentConnection.ConnectionString;
        }
    }
}

